diff --git a/plugins/explore/src/components/ExplorePage/ExploreTabs.tsx b/plugins/explore/src/components/ExplorePage/ExploreTabs.tsx
index 24fbf0039c..0415dd97ae 100644
--- a/plugins/explore/src/components/ExplorePage/ExploreTabs.tsx
+++ b/plugins/explore/src/components/ExplorePage/ExploreTabs.tsx
@@ -16,7 +16,7 @@
import { TabbedLayout } from '@backstage/core';
import React from 'react';
import { DomainExplorerContent } from '../DomainExplorerContent';
-import { OrganizationExplorerContent } from '../OrganizationExplorerContent';
+import { GroupsExplorerContent } from '../GroupsExplorerContent';
import { ToolExplorerContent } from '../ToolExplorerContent';
export const ExploreTabs = () => (
@@ -24,8 +24,8 @@ export const ExploreTabs = () => (
-
-
+
+
diff --git a/plugins/explore/src/components/OrganizationExplorerContent/OrganizationExplorerContent.tsx b/plugins/explore/src/components/GroupsExplorerContent/GroupsExplorerContent.tsx
similarity index 75%
rename from plugins/explore/src/components/OrganizationExplorerContent/OrganizationExplorerContent.tsx
rename to plugins/explore/src/components/GroupsExplorerContent/GroupsExplorerContent.tsx
index 4e05cc2c6c..c4d46206e4 100644
--- a/plugins/explore/src/components/OrganizationExplorerContent/OrganizationExplorerContent.tsx
+++ b/plugins/explore/src/components/GroupsExplorerContent/GroupsExplorerContent.tsx
@@ -15,16 +15,16 @@
*/
import { Content, ContentHeader, SupportButton } from '@backstage/core';
import React from 'react';
-import { OrganizationDiagram } from './OrganizationDiagram';
+import { GroupsDiagram } from './GroupsDiagram';
-export const OrganizationExplorerContent = () => {
+export const GroupsExplorerContent = () => {
return (
-
- Explore your organization.
+
+ Explore your groups.
-
+
);
};
diff --git a/plugins/explore/src/components/OrganizationExplorerContent/index.ts b/plugins/explore/src/components/GroupsExplorerContent/index.ts
similarity index 88%
rename from plugins/explore/src/components/OrganizationExplorerContent/index.ts
rename to plugins/explore/src/components/GroupsExplorerContent/index.ts
index 87b08eba52..4d88f40dde 100644
--- a/plugins/explore/src/components/OrganizationExplorerContent/index.ts
+++ b/plugins/explore/src/components/GroupsExplorerContent/index.ts
@@ -13,4 +13,4 @@
* See the License for the specific language governing permissions and
* limitations under the License.
*/
-export { OrganizationExplorerContent } from './OrganizationExplorerContent';
+export { GroupsExplorerContent } from './GroupsExplorerContent';
diff --git a/plugins/explore/src/components/OrganizationExplorerContent/OrganizationDiagram.tsx b/plugins/explore/src/components/GroupsExplorerContent/GroupsDiagram.tsx
similarity index 97%
rename from plugins/explore/src/components/OrganizationExplorerContent/OrganizationDiagram.tsx
rename to plugins/explore/src/components/GroupsExplorerContent/GroupsDiagram.tsx
index e3a6826835..99157b878f 100644
--- a/plugins/explore/src/components/OrganizationExplorerContent/OrganizationDiagram.tsx
+++ b/plugins/explore/src/components/GroupsExplorerContent/GroupsDiagram.tsx
@@ -105,9 +105,9 @@ function RenderNode(props: DependencyGraphTypes.RenderNodeProps) {
}
/**
* Dynamically generates a diagram of an organization.
*/
-export function OrganizationDiagram() {
+export function GroupsDiagram() {
const nodes = new Array<{ id: string; kind: string; name: string }>();
const edges = new Array<{ from: string; to: string; label: string }>();
@@ -105,9 +105,9 @@ function RenderNode(props: DependencyGraphTypes.RenderNodeProps) {
}
/**
- * Dynamically generates a diagram of an organization.
+ * Dynamically generates a diagram of groups registered in the catalog.
*/